@@ -17,9 +17,16 @@ sub tempdir {
 sub create {
     my $d = $tempdir;
     die unless $d and -d $d;
+    my @created;
     for (@_) { 
-        create_file(File::Spec->catfile($d, $_), $_) or die; 
+        my $path = File::Spec->catfile($d, $_);
+        my $text = $_;
+        $text =~ s/[^\x20-\x7e]/?/g;
+        if ( create_file($path, $text) ) {
+            push @created, $path;
+        }
     } 
+    return @created;
 }
 
 sub listdir {
